# Sanic Extension

_Future home to `sanic-ext`. An add-on package for [Sanic](https://github.com/sanic-org/sanic)._ 

First alpha release aiming to coincide with Sanic v21.9

[More info](https://community.sanicframework.org/t/openapi-next-generation-with-built-in-validation/843)
